```{eval-rst}
.. role:: small
```

```{eval-rst}
.. role:: smaller
```

```{include} ../README.md
```

# Latest additions

```{include} release-notes/release-latest.md
```

See {doc}`/release-notes/index` for more.

```{toctree}
:hidden: true
:maxdepth: 1

tutorials/index
api
concatenation
fileformat-prose
interoperability
benchmarks
contributing
release-notes/index
references
```

# News

```{include} news.md
```
